<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Грубий</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="51"/>
        <source>Mouse</source>
        <translation>Мишка</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Параметри менеджера файлів</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="26"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="31"/>
        <source>Appearance</source>
        <translation>Вигляд</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="36"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="41"/>
        <location filename="../obconf.ui" line="102"/>
        <source>Windows</source>
        <translation>Вікна</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="46"/>
        <source>Move &amp; Resize</source>
        <translation>Перемістити і Змінити розмір</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="56"/>
        <source>Desktops</source>
        <translation>Стільниці</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="61"/>
        <source>Margins</source>
        <translation>Поля</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="66"/>
        <source>Dock</source>
        <translation>Док</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="125"/>
        <source>Window Titles</source>
        <translation>Заголовки вікон</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="131"/>
        <source>Button order:</source>
        <translation>Послідовність кнопок:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="427"/>
        <source>Moving and Resizing Windows</source>
        <translation>Пересування і зміна розмірів вікон</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="530"/>
        <source>Information Dialog</source>
        <translation>Діалог інформації</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="689"/>
        <source>Focusing Windows</source>
        <translation>Фокусування вікон</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="698"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Фокусування вікон, якщо вказівник миші розташовано над ними</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>Titlebar</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="893"/>
        <source>Desktop Margins</source>
        <translation>Поля стільниці</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="899"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Поля стільниці — це зарезервовані ділянки на краю вашого екрана. Нові вікна не будуть поміщені по за цими межами, а розгорнені вікна не затулятимуть їх.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="909"/>
        <source>Left:</source>
        <translation>Ліворуч:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="923"/>
        <location filename="../obconf.ui" line="944"/>
        <location filename="../obconf.ui" line="965"/>
        <location filename="../obconf.ui" line="986"/>
        <source>px</source>
        <translation>пікселів</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="930"/>
        <source>Top:</source>
        <translation>Згори:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="951"/>
        <source>Right:</source>
        <translation>Праворуч:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="972"/>
        <source>Bottom:</source>
        <translation>Знизу:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="317"/>
        <source>All monitors</source>
        <translation>Всі монітори</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="322"/>
        <source>The active monitor</source>
        <translation>Активний монітор</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="327"/>
        <source>The monitor with the mouse</source>
        <translation>Монітор з мишкою</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="342"/>
        <source>Primary Monitor</source>
        <translation>Головний монітор</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="348"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Головний монітор - це монітор, де Openbox поміщає діалоги, наприклад, як діалог прокрутки вікон.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="369"/>
        <source>Fixed Monitor</source>
        <translation>Фіксований монітор</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="374"/>
        <source>Active Monitor</source>
        <translation>Активний монітор</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="379"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Монітор з вказівником миші</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="537"/>
        <location filename="../obconf.ui" line="566"/>
        <source>Centered</source>
        <translation>У центрі</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>From left edge</source>
        <translation>Від лівого краю</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="547"/>
        <source>From right edge</source>
        <translation>Від правого краю</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="571"/>
        <source>From top edge</source>
        <translation>Від верхнього краю</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="576"/>
        <source>From bottom edge</source>
        <translation>Від нижнього краю</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="629"/>
        <source>When resizing terminal windows</source>
        <translation>При зміні розмірів термінального вікна</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="634"/>
        <source>Always</source>
        <translation>Завжди</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="639"/>
        <source>Never</source>
        <translation>Ніколи</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="648"/>
        <source>Centered on the window</source>
        <translation>Центровано на вікні</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="653"/>
        <source>Above the window</source>
        <translation>Над вікном</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="658"/>
        <source>Fixed position on screen</source>
        <translation>Фіксована позиція на екрані</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="773"/>
        <source>Maximizes the window</source>
        <translation>Максимізує вікно</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="778"/>
        <source>Shades the window</source>
        <translation>Затіняє вікно</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="141"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Піктограма вікна
L: Мітка вікна (Назва)
I: Піктограма (Зменшити)
M: Розгорнути
C: Закрити
S: Затінити (Згорнути)
D: Розмістити всюди (На всіх стільницях)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="332"/>
        <source>Primary monitor</source>
        <translation>Головний монітор</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1013"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Док - це спеціальний контейнер для &quot;dockapps&quot;, або програм доку. Він невидимий на екрані, поки не запущено програму доку. Програми доку можна використовувати для показу таких програм як годинник, або для системного лотка.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1029"/>
        <source>Position</source>
        <translation>Позиція</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>&amp;Position:</source>
        <translation>&amp;Позиція:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1055"/>
        <source>Top Left</source>
        <translation>Зверху зліва</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1060"/>
        <source>Top</source>
        <translation>Зверху</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1065"/>
        <source>Top Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1070"/>
        <source>Left</source>
        <translation>Зліва</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1075"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1080"/>
        <source>Bottom Left</source>
        <translation>Знизу зліва</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1085"/>
        <source>Bottom</source>
        <translation>Знизу</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1090"/>
        <source>Bottom Right</source>
        <translation>Знизу справа</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1095"/>
        <source>Floating</source>
        <translation>Плаваюча</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1109"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Плаваюча позиція:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1134"/>
        <source>x</source>
        <translation>х</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1150"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Дозволити &amp;вікнам розміщуватися поза областю дока</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1157"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Орієнтація: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1171"/>
        <source>Vertical</source>
        <translation>Вертикальна</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1176"/>
        <source>Horizontal</source>
        <translation>Горизонтальна</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1187"/>
        <source>Stacking</source>
        <translation>Штабелювання</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1193"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Помістити док &amp;над іншими вікнами</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1200"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>До&amp;зволити доку бути одночасно над і під вікнами</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1207"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Помістити док &amp;під іншими вікнами</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1217"/>
        <source>Hiding</source>
        <translation>Приховування</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1223"/>
        <source>&amp;Delay before hiding:</source>
        <translation>&amp;Затримка перед приховуванням:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1233"/>
        <source>Delay before &amp;showing:</source>
        <translation>Затримка перед &amp;показом:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1263"/>
        <source>&amp;Hide off screen</source>
        <translation>С&amp;ховати з екрана</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1294"/>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="84"/>
        <source>&amp;Install a new theme...</source>
        <translation>&amp;Встановити нову тему...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="91"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Створити &amp;архів теми (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="108"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Вікна зберігають границі, коли є без оформлення</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="115"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>Ані&amp;мація піктограм і відновлення</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="219"/>
        <source>&amp;Active window title: </source>
        <translation>Назва &amp;активного вікна: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="229"/>
        <source>&amp;Inactive window title: </source>
        <translation>Назва &amp;неактивного вікна: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="239"/>
        <source>Menu &amp;header: </source>
        <translation>Заголово&amp;к меню: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="249"/>
        <source>&amp;Menu Item: </source>
        <translation>П&amp;ункт меню: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="259"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Активне ві&amp;дображення на екрані: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="269"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Неактивне від&amp;ображення на екрані: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="283"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Фокусуватися на &amp;новому вікні коли воно з&apos;являється</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="290"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Помістити нові вікна під вказівником миші</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="297"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Центрувати нові вікна коли вони розташовуються</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="306"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Надавати перевагу розташуванню нових вікон &amp;на:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="358"/>
        <source>Primary &amp;monitor:</source>
        <translation>Головний &amp;монітор:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="387"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Фіксований монітор:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="433"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Оновлювати вміст вікна при &amp;зміні розміру</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="440"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Відс&amp;туп під час перетягування:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="460"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Сила опору до інших &amp;вікон:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="480"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Сила опору до меж &amp;екрана:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="500"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>&amp;Час очікування до перемикання:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="520"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>Перемикати робочий стіл під час переміщення вікна за край екрана</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="555"/>
        <source>Fixed &amp;y position:</source>
        <translation>Фіксован&amp;а y-позиція:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="584"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>&amp;Позиція інформаційного діалогу:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="594"/>
        <source>Fixed &amp;x position:</source>
        <translation>Фіксована &amp;x позиція:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="604"/>
        <source>Show &amp;information dialog:</source>
        <translation>Показати &amp;інформаційний діалог:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>Затримка перед &amp;фокусуванням і розгортанням вікна:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="730"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Пересовувати фокус під мишкою п&amp;ри перемиканні стільниць</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="737"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Пересовувати &amp;фокус під мишкою коли мишка не рухається</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="744"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Підня&amp;ти вікна, коли вказівник миші рухається над ними</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="762"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Подвійне клацання на панель &amp;заголовка:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="786"/>
        <source>Double click ti&amp;me:</source>
        <translation>Час подвійного &amp;клацання:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="826"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Показати &amp;повідомлення при перемиканні стільниць</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="833"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>&amp;Час показу повідомлень для:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="856"/>
        <source>&amp;Number of desktops: </source>
        <translation>Кількість &amp;стільниць: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="879"/>
        <source>&amp;Desktop names:</source>
        <translation>&amp;Назви стільниць:</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../mouse.cpp" line="56"/>
        <source>Custom actions</source>
        <translation>Дії користувача</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="67"/>
        <location filename="../desktops.cpp" line="89"/>
        <location filename="../desktops.cpp" line="101"/>
        <source>(Unnamed desktop)</source>
        <translation>(Стільниця без назви)</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="78"/>
        <source>About ObConf-Qt</source>
        <translation>Про ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="79"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Менеджер налаштувань для Openbox

Всі права застережено (c) 2014-2015

Автори:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Програма базується на ObConf, розробленим наступними розробниками:
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../theme.cpp" line="152"/>
        <source>Choose an Openbox theme</source>
        <translation>Виберіть тему Openbox</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>«%1» встановлено до %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; успішно створено</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Неможливо створити архів теми &quot;%1&quot;.
Появилися наступні помилки:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="180"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Неможливо запустити команду &quot;tar&quot;: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Неможливо створити теку &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; не виглядає на справжню теку теми Openbox</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="187"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Неможливо розпакувати файл «%1».
Впевніться, що до «%2» можна записувати і що файл є справжнім архівом теми Openbox.
Сталися такі помилки :
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>Помилка ObConf</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Синтакс: obconf [параметри] [АРХІВ.obt]

Параметри:
  --help                Показати цю допомогу і вийти
  --version             Показати версію і вийти
  --install АРХІВ.obt Встановлює даний архів теми і вибирає її
  --archive ТЕМА       Створює архів теми з заданої теки теми
  --config-file ФАЙЛ    Вказати шлях до файлу налаштування для використання
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install вимагає аргументу
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive вимагає аргументу
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file вимагає аргументу
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="206"/>
        <source>Platform Unsupported</source>
        <translation>Непідтримувана платформа</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="207"/>
        <source>ObConf-Qt is unsupported under Wayland.
</source>
        <translation>ObConf-Qt не підтримується у Wayland.
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="241"/>
        <location filename="../obconf-qt.cpp" line="256"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="242"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Помилка завантаження rc.xml. Можливо ви встановили Openbox не правильно.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="254"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Помилка обробки файлу конфігурації Openbox. Ваш файл конфігурації не є файлом XML.

Повідомлення: %1</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Всі права застережено (c) 2003-2008   Dana Jansens
Всі права застережено (c) 2003        Tim Riley
Всі права застережено (c) 2007        Javeed Shaikh
Всі права застережено (c) 2013        Hong Jen Yee (PCMan)

Ця програма поставляється без жодних гарантій.
Це вільне програмне забезпечення і ви можете поширювати
його за певних умов. Див. файл з назвою COPYING для деталей.

</translation>
    </message>
</context>
</TS>
